BleRepository class

Constructors

BleRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readCharacteristic(BluetoothCharacteristic characteristic) Future<List<int>>
requestMtu(BluetoothDevice device, int mtuSize) Future<void>
toString() String
A string representation of this object.
inherited
writeDataCharacteristic(BluetoothCharacteristic characteristic, Uint8List data) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited